[jboss-cvs] JBossAS SVN: r84789 - in projects/webbeans-ri-int/trunk/microcontainer/src: test/java/org/jboss/test/webbeans/deployers and 3 other directories.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Thu Feb 26 05:50:34 EST 2009


Author: alesj
Date: 2009-02-26 05:50:34 -0500 (Thu, 26 Feb 2009)
New Revision: 84789

Added:
   projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockBootDeployer.java
   projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockEjbDiscovery.java
   projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockEjbResolver.java
   projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockWBBootstrap.java
   projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/WBDEWrapper.java
   projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/test/BootDeployerTestCase.java
   projects/webbeans-ri-int/trunk/microcontainer/src/test/resources/org/jboss/test/webbeans/deployers/test/BootDeployerTestCase.xml
Modified:
   projects/webbeans-ri-int/trunk/microcontainer/src/main/java/org/jboss/webbeans/integration/microcontainer/deployer/env/WebBeansBootstrapDeployer.java
   projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/VFSTestSuite.java
Log:
Fix bootstrap + add test for it.

Modified: projects/webbeans-ri-int/trunk/microcontainer/src/main/java/org/jboss/webbeans/integration/microcontainer/deployer/env/WebBeansBootstrapDeployer.java
===================================================================
--- projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/VFSTestSuite.java	2009-02-26 10:42:33 UTC (rev 84788)
+++ projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/VFSTestSuite.java	2009-02-26 10:50:34 UTC (rev 84789)
@@ -24,7 +24,7 @@
 import junit.framework.Test;
 import junit.framework.TestSuite;
 import junit.textui.TestRunner;
-
+import org.jboss.test.webbeans.deployers.test.BootDeployerTestCase;
 import org.jboss.test.webbeans.deployers.test.PostDeployersTestCase;
 import org.jboss.test.webbeans.deployers.test.WBDiscoveryEnvTestCase;
 
@@ -46,6 +46,7 @@
 
       suite.addTest(WBDiscoveryEnvTestCase.suite());
       suite.addTest(PostDeployersTestCase.suite());
+      suite.addTest(BootDeployerTestCase.suite());
 
       return suite;
    }

Added: projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockBootDeployer.java
===================================================================
--- projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockBootDeployer.java	                        (rev 0)
+++ projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockBootDeployer.java	2009-02-26 10:50:34 UTC (rev 84789)
@@ -0,0 +1,97 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2008, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.test.webbeans.deployers.support;
+
+import org.jboss.beans.metadata.spi.BeanMetaData;
+import org.jboss.beans.metadata.spi.ValueMetaData;
+import org.jboss.beans.metadata.spi.builder.BeanMetaDataBuilder;
+import org.jboss.deployers.spi.DeploymentException;
+import org.jboss.deployers.spi.deployer.DeploymentStages;
+import org.jboss.deployers.spi.deployer.helpers.AbstractSimpleRealDeployer;
+import org.jboss.deployers.structure.spi.DeploymentUnit;
+import org.jboss.webbeans.context.api.BeanStore;
+import org.jboss.webbeans.context.api.helpers.ConcurrentHashMapBeanStore;
+import org.jboss.webbeans.integration.microcontainer.deployer.env.WebBeanDiscoveryEnvironment;
+
+/**
+ * @author <a href="mailto:ales.justin at jboss.org">Ales Justin</a>
+ */
+public class MockBootDeployer extends AbstractSimpleRealDeployer<WebBeanDiscoveryEnvironment>
+{
+   public MockBootDeployer()
+   {
+      super(WebBeanDiscoveryEnvironment.class);
+      setTopLevelOnly(true);
+      setStage(DeploymentStages.PRE_REAL);
+      addOutput(BeanMetaData.class);
+   }
+
+   public void deploy(DeploymentUnit unit, WebBeanDiscoveryEnvironment env) throws DeploymentException
+   {
+      String unitName = unit.getName();
+
+      String envName = unitName + "_JBossWebBeanDiscovery";
+      BeanMetaDataBuilder envWrapper = BeanMetaDataBuilder.createBuilder(envName, "org.jboss.test.webbeans.deployers.support.WBDEWrapper");
+      envWrapper.addConstructorParameter(WebBeanDiscoveryEnvironment.class.getName(), env);
+      unit.addAttachment(envName + "_" + BeanMetaData.class.getSimpleName(), envWrapper.getBeanMetaData());
+
+      String bootstrapName = unitName + "_WebBeansBootstrap";
+      BeanMetaDataBuilder bootstrap = BeanMetaDataBuilder.createBuilder(bootstrapName, "org.jboss.test.webbeans.deployers.support.MockWBBootstrap");
+      bootstrap.addPropertyMetaData("webBeanDiscovery", bootstrap.createInject(envName));
+      bootstrap.addPropertyMetaData("ejbDiscovery", createEjbConnector("JBossEjbDiscovery", "org.jboss.test.webbeans.deployers.support.MockEjbDiscovery", unit));
+      bootstrap.addPropertyMetaData("ejbResolver", createEjbConnector("JBossEjbResolver", "org.jboss.test.webbeans.deployers.support.MockEjbResolver", unit));
+      bootstrap.addPropertyMetaData("applicationContext", createBeanStore());
+      bootstrap.setCreate("initialize");
+      bootstrap.setStart("boot");
+      bootstrap.setDestroy("shutdown");
+      unit.addAttachment(bootstrapName + "_" + BeanMetaData.class.getSimpleName(), bootstrap.getBeanMetaData());
+   }
+
+   /**
+    * Create new bean store.
+    *
+    * @return the bean store instance
+    */
+   protected BeanStore createBeanStore()
+   {
+      return new ConcurrentHashMapBeanStore();
+   }
+
+   /**
+    * Create ejb connector.
+    *
+    * @param name the connector name
+    * @param bean the bean to create
+    * @param unit the deployment unit
+    * @return new inject metadata
+    */
+   protected ValueMetaData createEjbConnector(String name, String bean, DeploymentUnit unit)
+   {
+      String beanName = unit.getName() + "_" + name;
+      BeanMetaDataBuilder builder = BeanMetaDataBuilder.createBuilder(beanName, bean);
+      builder.setFactory(name);
+      builder.setFactoryMethod("createBean");
+      builder.addPropertyMetaData("deploymentUnit", unit);
+      unit.addAttachment(beanName + "_" + BeanMetaData.class.getSimpleName(), builder.getBeanMetaData());
+      return builder.createInject(beanName);
+   }
+}

Added: projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockEjbDiscovery.java
===================================================================
--- projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockEjbDiscovery.java	                        (rev 0)
+++ projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockEjbDiscovery.java	2009-02-26 10:50:34 UTC (rev 84789)
@@ -0,0 +1,43 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2008, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.test.webbeans.deployers.support;
+
+import java.util.Collections;
+
+import org.jboss.webbeans.bootstrap.spi.EjbDiscovery;
+import org.jboss.webbeans.ejb.spi.EjbDescriptor;
+import org.jboss.deployers.structure.spi.DeploymentUnit;
+
+/**
+ * @author <a href="mailto:ales.justin at jboss.org">Ales Justin</a>
+ */
+public class MockEjbDiscovery implements EjbDiscovery
+{
+   public void setDeploymentUnit(DeploymentUnit unit)
+   {
+   }
+
+   public Iterable<EjbDescriptor<?>> discoverEjbs()
+   {
+      return Collections.emptySet();
+   }
+}
\ No newline at end of file

Added: projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockEjbResolver.java
===================================================================
--- projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockEjbResolver.java	                        (rev 0)
+++ projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockEjbResolver.java	2009-02-26 10:50:34 UTC (rev 84789)
@@ -0,0 +1,69 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2008, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.test.webbeans.deployers.support;
+
+import java.lang.annotation.Annotation;
+import javax.inject.manager.InjectionPoint;
+
+import org.jboss.deployers.structure.spi.DeploymentUnit;
+import org.jboss.webbeans.ejb.spi.EjbResolver;
+import org.jboss.webbeans.resources.spi.NamingContext;
+
+/**
+ * @author <a href="mailto:ales.justin at jboss.org">Ales Justin</a>
+ */
+public class MockEjbResolver implements EjbResolver
+{
+   public void setDeploymentUnit(DeploymentUnit unit)
+   {
+   }
+   
+   public Object resolveEjb(InjectionPoint injectionPoint, NamingContext namingContext)
+   {
+      return null;
+   }
+
+   public Object resolvePersistenceContext(InjectionPoint injectionPoint, NamingContext namingContext)
+   {
+      return null;
+   }
+
+   public Object resolveResource(InjectionPoint injectionPoint, NamingContext namingContext)
+   {
+      return null;
+   }
+
+   public Class<? extends Annotation> getEJBAnnotation()
+   {
+      return null;
+   }
+
+   public Class<? extends Annotation> getPersistenceContextAnnotation()
+   {
+      return null;
+   }
+
+   public Class<? extends Annotation> getResourceAnnotation()
+   {
+      return null;
+   }
+}
\ No newline at end of file

Added: projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockWBBootstrap.java
===================================================================
--- projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockWBBootstrap.java	                        (rev 0)
+++ projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/MockWBBootstrap.java	2009-02-26 10:50:34 UTC (rev 84789)
@@ -0,0 +1,53 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2008, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.test.webbeans.deployers.support;
+
+import javax.inject.manager.Manager;
+
+import org.jboss.webbeans.bootstrap.api.helpers.AbstractBootstrap;
+
+/**
+ * @author <a href="mailto:ales.justin at jboss.org">Ales Justin</a>
+ */
+public class MockWBBootstrap extends AbstractBootstrap
+{
+   public MockWBBootstrap()
+   {
+   }
+
+   public void initialize()
+   {
+   }
+
+   public Manager getManager()
+   {
+      return null;
+   }
+
+   public void boot()
+   {
+   }
+
+   public void shutdown()
+   {
+   }
+}
\ No newline at end of file

Added: projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/WBDEWrapper.java
===================================================================
--- projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/WBDEWrapper.java	                        (rev 0)
+++ projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/support/WBDEWrapper.java	2009-02-26 10:50:34 UTC (rev 84789)
@@ -0,0 +1,50 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2008, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.test.webbeans.deployers.support;
+
+import java.net.URL;
+
+import org.jboss.webbeans.bootstrap.spi.WebBeanDiscovery;
+import org.jboss.webbeans.integration.microcontainer.deployer.env.WebBeanDiscoveryEnvironment;
+
+/**
+ * @author <a href="mailto:ales.justin at jboss.org">Ales Justin</a>
+ */
+public class WBDEWrapper implements WebBeanDiscovery
+{
+   protected final WebBeanDiscoveryEnvironment environment;
+
+   public WBDEWrapper(WebBeanDiscoveryEnvironment environment)
+   {
+      this.environment = environment;
+   }
+
+   public Iterable<Class<?>> discoverWebBeanClasses()
+   {
+      return environment.getWebBeanClasses();
+   }
+
+   public Iterable<URL> discoverWebBeansXml()
+   {
+      return environment.getWebBeansXml();
+   }
+}
\ No newline at end of file

Copied: projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/test/BootDeployerTestCase.java (from rev 84737, projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/test/PostDeployersTestCase.java)
===================================================================
--- projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/test/BootDeployerTestCase.java	                        (rev 0)
+++ projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/test/BootDeployerTestCase.java	2009-02-26 10:50:34 UTC (rev 84789)
@@ -0,0 +1,62 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2008, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.test.webbeans.deployers.test;
+
+import junit.framework.Test;
+import org.jboss.deployers.structure.spi.DeploymentUnit;
+import org.jboss.virtual.VirtualFile;
+import org.jboss.webbeans.bootstrap.api.Bootstrap;
+
+/**
+ * Test boot deployer.
+ *
+ * @author <a href="mailto:ales.justin at jboss.org">Ales Justin</a>
+ */
+public class BootDeployerTestCase extends AbstractWebBeansTest
+{
+   public BootDeployerTestCase(String name)
+   {
+      super(name);
+   }
+
+   public static Test suite()
+   {
+      return suite(BootDeployerTestCase.class);
+   }
+
+   public void testEar() throws Exception
+   {
+      VirtualFile ear = createBasicEar();
+      DeploymentUnit earDU = assertDeploy(ear);
+      try
+      {
+         String earName = earDU.getName();
+         String bootName = earName + "_WebBeansBootstrap";
+         Object boot = getBean(bootName);
+         assertInstanceOf(boot, Bootstrap.class, false);
+      }
+      finally
+      {
+         undeploy(earDU);
+      }
+   }
+}
\ No newline at end of file

Copied: projects/webbeans-ri-int/trunk/microcontainer/src/test/resources/org/jboss/test/webbeans/deployers/test/BootDeployerTestCase.xml (from rev 84737, projects/webbeans-ri-int/trunk/microcontainer/src/test/resources/org/jboss/test/webbeans/deployers/test/PostDeployersTestCase.xml)
===================================================================
--- projects/webbeans-ri-int/trunk/microcontainer/src/test/resources/org/jboss/test/webbeans/deployers/test/BootDeployerTestCase.xml	                        (rev 0)
+++ projects/webbeans-ri-int/trunk/microcontainer/src/test/resources/org/jboss/test/webbeans/deployers/test/BootDeployerTestCase.xml	2009-02-26 10:50:34 UTC (rev 84789)
@@ -0,0 +1,18 @@
+<deployment xmlns="urn:jboss:bean-deployer:2.0">
+
+  <bean name="EarStructure" class="org.jboss.test.deployers.vfs.structure.ear.support.MockEarStructureDeployer"/>
+  <bean name="WarStructure" class="org.jboss.test.deployers.vfs.structure.war.support.MockWarStructureDeployer"/>
+
+  <bean name="JWBMDDeployer" class="org.jboss.webbeans.integration.microcontainer.deployer.ext.JBossWebBeansMetaDataDeployer"/>
+  <bean name="WBFilesDeployer" class="org.jboss.webbeans.integration.microcontainer.deployer.metadata.WebBeansFilesDeployer"/>
+  <bean name="WBDiscoveryDeployer" class="org.jboss.webbeans.integration.microcontainer.deployer.env.WebBeanDiscoveryDeployer"/>
+
+  <bean name="BootDeployer" class="org.jboss.test.webbeans.deployers.support.MockBootDeployer"/>
+
+  <!-- Mock EJB utils -->
+
+  <beanfactory name="JBossEjbResolver" class="org.jboss.test.webbeans.deployers.support.MockEjbResolver"/>
+
+  <beanfactory name="JBossEjbDiscovery" class="org.jboss.test.webbeans.deployers.support.MockEjbDiscovery"/>
+
+</deployment>




More information about the jboss-cvs-commits mailing list
--- projects/webbeans-ri-int/trunk/microcontainer/src/main/java/org/jboss/webbeans/integration/microcontainer/deployer/env/WebBeansBootstrapDeployer.java	2009-02-26 10:42:33 UTC (rev 84788)
+++ projects/webbeans-ri-int/trunk/microcontainer/src/main/java/org/jboss/webbeans/integration/microcontainer/deployer/env/WebBeansBootstrapDeployer.java	2009-02-26 10:50:34 UTC (rev 84789)
@@ -63,7 +63,7 @@
       bootstrap.addPropertyMetaData("applicationContext", createBeanStore());
       bootstrap.setCreate("initialize");
       bootstrap.setStart("boot");
-      bootstrap.setDestroy("shutdown");
+      //bootstrap.setDestroy("shutdown");
       unit.addAttachment(bootstrapName + "_" + BeanMetaData.class.getSimpleName(), bootstrap.getBeanMetaData());
    }
 
@@ -83,14 +83,16 @@
     * @param name the connector name
     * @param bean the bean to create
     * @param unit the deployment unit
     * @return new bean metadata
     */
    protected ValueMetaData createEjbConnector(String name, String bean, DeploymentUnit unit)
    {
-      BeanMetaDataBuilder builder = BeanMetaDataBuilder.createBuilder(unit.getName() + "_" + name, bean);
+      String beanName = unit.getName() + "_" + name;
+      BeanMetaDataBuilder builder = BeanMetaDataBuilder.createBuilder(beanName, bean);
       builder.setFactory(name);
       builder.setFactoryMethod("createBean");
       builder.addPropertyMetaData("deploymentUnit", unit);
-      return builder.getBeanMetaData();
+      unit.addAttachment(beanName + "_" + BeanMetaData.class.getSimpleName(), builder.getBeanMetaData());
+      return builder.createInject(beanName);
    }
 }
@@ -83,14 +83,16 @@
     * @param bean the bean to create
     * @param unit the deployment unit
-    * @return new bean metadata
+    * @return new inject metadata
     */
    protected ValueMetaData createEjbConnector(String name, String bean, DeploymentUnit unit)

Modified: projects/webbeans-ri-int/trunk/microcontainer/src/test/java/org/jboss/test/webbeans/deployers/VFSTestSuite.java
===================================================================